let currentStationId = null;
let isCurrentlyPlaying = false;

chrome.storage.local.get(['currentStation', 'isPlaying'], (result) => {
    if (result.currentStation) {
        currentStationId = result.currentStation;
        isCurrentlyPlaying = result.isPlaying || false;
    }
});

async function createOffscreenDocument() {
    try {
        await chrome.offscreen.createDocument({
            url: 'offscreen.html',
            reasons: ['AUDIO_PLAYBACK'],
            justification: 'Playing audio in background'
        });
    } catch (error) {
        // נתעלם מהשגיאה אם המסמך כבר קיים
        if (!error.message.includes('Only a single offscreen document')) {
            console.error('שגיאה ביצירת offscreen document:', error);
        }
    }
}

async function saveCurrentState() {
    await chrome.storage.local.set({
        currentStation: currentStationId,
        isPlaying: isCurrentlyPlaying
    });
}

chrome.runtime.onMessage.addListener((request, sender, sendResponse) => {
    (async () => {
        try {
            if (request.target === 'offscreen') {
                // העברת הודעה מ-popup ל-offscreen
                await createOffscreenDocument();
                chrome.runtime.sendMessage(request);
                
                if (request.action === 'play') {
                    currentStationId = request.stationId;
                    isCurrentlyPlaying = true;
                } else if (request.action === 'stop') {
                    isCurrentlyPlaying = false;
                }
                
                await saveCurrentState();
            } else if (request.action === 'getStatus') {
                // החזרת מצב נוכחי ל-popup
                sendResponse({
                    isPlaying: isCurrentlyPlaying,
                    currentStation: currentStationId
                });
            }
        } catch (error) {
            console.error('שגיאה ב-background script:', error);
            sendResponse({ error: error.message });
        }
    })();
    
    return true;
});
